@@ -31,6 +31,9 @@ async def head_db(uri: str, db: str) -> HeadDbOk:
     of information about the specified database. Since the response body is empty,
     using the HEAD method is a lightweight way to check if the database exists already or not
     '''
+    if not db:
+        res = HeadDbErr('Bad Request', '\'db\' parameter missing')
+        raise ResultException(res)
     
     url: str = f'{uri}/{db}'
 
